import os

_version = "1.0.7"

_pipelist = [
    "data",
    'count',
    'analysis',
    'report',
    'clean',
    #'mkref',
    'run',
    'list',
]
_root_dir = os.path.abspath(os.path.dirname(__file__))
